@@ -72,14 +72,16 @@ impl ValidSig {
 #[derive(Clone)]
 pub struct Decrypted {
     valid_sigs: Vec<ValidSig>,
-    content: Vec<u8>,
+    content: Option<Vec<u8>>,
 }
 
 #[pymethods]
 impl Decrypted {
     #[getter]
-    pub fn bytes(&self) -> Cow<[u8]> {
-        Cow::Borrowed(&self.content)
+    pub fn bytes(&self) -> Option<Cow<'_, [u8]>> {
+        self.content
+            .as_ref()
+            .map(|content| Cow::Borrowed(&content[..]))
     }
 
     #[getter]
@@ -91,6 +93,7 @@ impl Decrypted {
 #[pymodule]
 fn pysequoia(_py: Python, m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<cert::Cert>()?;
+    m.add_class::<cert::Profile>()?;
     m.add_class::<signature::Sig>()?;
     m.add_class::<notation::Notation>()?;
     m.add_class::<sign::SignatureMode>()?;
